@@ -167,7 +167,7 @@ INTRO_FILES = itertools.chain.from_iterable(
         do_nothing_list(external_programs_dir,
                         [MY_ASSERT_HELPER_PROGRAM,
                          MY_SETUP_HELPER_PROGRAM,
-                         SYSTEM_UNDER_TEST,
+                         'my-program-that-reads-stdin',
                          ]),
 
         do_nothing_list(home_dir / 'bin',
