@@ -19,9 +19,9 @@ from exactly_lib.processing.standalone import result_reporting
 from exactly_lib.processing.standalone import result_reporting as processing_result_reporting
 from exactly_lib.processing.test_case_processing import AccessorError
 from exactly_lib.section_document.section_element_parsing import SectionElementParser
-from exactly_lib.test_case import actor
 from exactly_lib.test_case import test_case_doc
-from exactly_lib.test_case.actor import ActionToCheck
+from exactly_lib.test_case.phases.act import actor
+from exactly_lib.test_case.phases.act.actor import ActionToCheck
 from exactly_lib.test_case.test_case_status import TestCaseStatus
 from exactly_lib.test_suite.file_reading.exception import SuiteParseError
 from exactly_lib.util import symbol_table
