@@ -1,4 +1,5 @@
 from . import matcher
 
-MATCH_REGEX_OR_GLOB_PATTERN_CHECK_ARGUMENT = 'matches'
+MATCH_REGEX_ARGUMENT = 'matches'
+MATCH_REGEX_ARGUMENT__SHORT = '~'
 PROGRAM_MATCHER_NAME = matcher.RUN_PROGRAM
