@@ -5,6 +5,7 @@ from exactly_lib.definitions.test_case import file_check_properties
 RUN_INSTRUCTION_NAME = program.RUN_PROGRAM_PRIMITIVE
 
 SHELL_INSTRUCTION_NAME = program.SHELL_COMMAND_TOKEN
+SYS_CMD_INSTRUCTION_NAME = program.SYSTEM_PROGRAM_TOKEN
 
 SYMBOL_REF_PROGRAM_INSTRUCTION_NAME = program.SYMBOL_PROGRAM_TOKEN
 
@@ -12,6 +13,8 @@ NEW_FILE_INSTRUCTION_NAME = 'file'
 
 NEW_DIR_INSTRUCTION_NAME = 'dir'
 
+COPY_INSTRUCTION_NAME = 'copy'
+
 ENV_VAR_INSTRUCTION_NAME = 'env'
 
 CHANGE_DIR_INSTRUCTION_NAME = 'cd'
@@ -21,7 +24,7 @@ SYMBOL_DEFINITION_INSTRUCTION_NAME = 'def'
 EXIT_CODE_INSTRUCTION_NAME = 'exit-code'
 
 CONTENTS_OF_STDOUT_INSTRUCTION_NAME = 'stdout'
-
+CONTENTS_OF_STDERR_INSTRUCTION_NAME = 'stderr'
 CONTENTS_OF_STDIN_INSTRUCTION_NAME = 'stdin'
 
 CONTENTS_OF_EXPLICIT_FILE_INSTRUCTION_NAME = file_check_properties.REGULAR_FILE_CONTENTS
