@@ -1,20 +1,19 @@
-import pathlib
-import subprocess
 from contextlib import contextmanager
-from typing import Optional, Callable
+from typing import Optional, Callable, ContextManager
 
 from exactly_lib.execution.impl.result import ActionThatRaisesPhaseStepFailureException
 from exactly_lib.execution.result import ActionToCheckOutcome, ExecutionFailureStatus, PhaseStepFailure, \
     PhaseStepFailureException
-from exactly_lib.test_case.actor import ActionToCheck
+from exactly_lib.test_case.app_env import ApplicationEnvironment
 from exactly_lib.test_case.os_services import OsServices
+from exactly_lib.test_case.phases.act.actor import ActionToCheck
+from exactly_lib.test_case.phases.act.adv_w_validation import AdvWValidation
+from exactly_lib.test_case.phases.act.execution_input import ActExecutionInput
 from exactly_lib.test_case.phases.instruction_environment import InstructionEnvironmentForPostSdsStep
-from exactly_lib.test_case.phases.setup import StdinConfiguration
-from exactly_lib.test_case.result.eh import ExitCodeOrHardError, new_eh_hard_error
+from exactly_lib.test_case.result.eh import ExitCodeOrHardError
 from exactly_lib.test_case.result.failure_details import FailureDetails
-from exactly_lib.test_case_file_structure.sandbox_directory_structure import stdin_contents_file
 from exactly_lib.util.file_utils import misc_utils
-from exactly_lib.util.file_utils.std import StdFiles, StdOutputFiles
+from exactly_lib.util.file_utils.std import StdOutputFiles
 
 PhaseStepFailureConstructorType = Callable[[ExecutionFailureStatus, FailureDetails], PhaseStepFailure]
 
@@ -37,14 +36,14 @@ class ActionToCheckExecutor:
                  environment_for_validate_post_setup: InstructionEnvironmentForPostSdsStep,
                  environment_for_other_steps: InstructionEnvironmentForPostSdsStep,
                  os_services: OsServices,
-                 stdin_configuration: StdinConfiguration,
+                 execution_input: AdvWValidation[ActExecutionInput],
                  exe_atc_and_skip_assertions: Optional[StdOutputFiles]):
         self.atc = atc
         self.environment_for_validate_post_setup = environment_for_validate_post_setup
         self.environment_for_other_steps = environment_for_other_steps
         self.os_services = os_services
         self.tcds = environment_for_other_steps.tcds
-        self.stdin_configuration = stdin_configuration
+        self.execution_input = execution_input
         self.exe_atc_and_skip_assertions = exe_atc_and_skip_assertions
 
         self._action_to_check_outcome = None
@@ -56,6 +55,19 @@ class ActionToCheckExecutor:
         """
         return self._action_to_check_outcome
 
+    def validate_execution_info(self,
+                                failure_con: PhaseStepFailureConstructorType,
+                                ) -> ActionThatRaisesPhaseStepFailureException:
+        def action():
+            mb_failure_message = self.execution_input.validate()
+            if mb_failure_message:
+                raise PhaseStepFailureException(
+                    failure_con(ExecutionFailureStatus.HARD_ERROR,
+                                FailureDetails.new_message(mb_failure_message))
+                )
+
+        return action
+
     def validate_post_setup(self,
                             failure_con: PhaseStepFailureConstructorType) -> ActionThatRaisesPhaseStepFailureException:
         def action():
@@ -82,7 +94,7 @@ class ActionToCheckExecutor:
 
     def execute(self, failure_con: PhaseStepFailureConstructorType) -> ActionThatRaisesPhaseStepFailureException:
         def action():
-            exit_code_or_hard_error = self._execute_with_stdin_handling()
+            exit_code_or_hard_error = self._do_execute()
             if not exit_code_or_hard_error.is_exit_code:
                 raise PhaseStepFailureException(
                     failure_con(ExecutionFailureStatus.HARD_ERROR,
@@ -91,41 +103,28 @@ class ActionToCheckExecutor:
 
         return action
 
-    def _execute_with_stdin_handling(self) -> ExitCodeOrHardError:
-        if self.stdin_configuration.has_custom_stdin:
-            file_name = self._custom_stdin_file_path()
-            return self._run_act_program_with_opened_stdin_file(file_name)
-        else:
-            return self._run_act_program_with_stdin_file(subprocess.DEVNULL)
-
-    def _run_act_program_with_opened_stdin_file(self, file_name: pathlib.Path) -> ExitCodeOrHardError:
-        try:
-            with file_name.open() as f_stdin:
-                return self._run_act_program_with_stdin_file(f_stdin)
-        except IOError as ex:
-            return new_eh_hard_error(FailureDetails.new_exception(
-                ex,
-                'Failure to open stdin file: ' + str(file_name)))
-
-    def _run_act_program_with_stdin_file(self, f_stdin) -> ExitCodeOrHardError:
+    def _do_execute(self) -> ExitCodeOrHardError:
         with self._std_output_files() as std_output_files:
-            std_files = StdFiles(f_stdin, std_output_files)
-            return self._run_act_program_with_std_files(std_files)
+            return self._do_execute_w_output_files(std_output_files)
 
-    def _run_act_program_with_std_files(self,
-                                        std_files: StdFiles) -> ExitCodeOrHardError:
-        exit_code_or_hard_error = self.atc.execute(self.environment_for_other_steps, self.os_services, std_files)
+    def _do_execute_w_output_files(self, output: StdOutputFiles) -> ExitCodeOrHardError:
+        exit_code_or_hard_error = self.atc.execute(
+            self.environment_for_other_steps,
+            self.os_services,
+            self.execution_input.resolve(self._app_env_for_execute()),
+            output,
+        )
         self._register_outcome(exit_code_or_hard_error)
         return exit_code_or_hard_error
 
     @contextmanager
-    def _std_output_files(self):
+    def _std_output_files(self) -> ContextManager[StdOutputFiles]:
         if self.exe_atc_and_skip_assertions is not None:
             yield self.exe_atc_and_skip_assertions
         else:
             sds = self.tcds.sds
-            with misc_utils.open_and_make_read_only_on_close__p(sds.result.stdout_file, 'w') as f_stdout:
-                with misc_utils.open_and_make_read_only_on_close__p(sds.result.stderr_file, 'w') as f_stderr:
+            with misc_utils.open_and_make_read_only_on_close__text(sds.result.stdout_file, 'w') as f_stdout:
+                with misc_utils.open_and_make_read_only_on_close__text(sds.result.stderr_file, 'w') as f_stderr:
                     yield StdOutputFiles(f_stdout, f_stderr)
 
     def _register_outcome(self, exit_code_or_hard_error: ExitCodeOrHardError):
@@ -135,14 +134,14 @@ class ActionToCheckExecutor:
                 self._store_exit_code(exit_code_or_hard_error.exit_code)
 
     def _store_exit_code(self, exitcode: int):
-        with misc_utils.open_and_make_read_only_on_close__p(self.tcds.sds.result.exitcode_file, 'w') as f:
+        with misc_utils.open_and_make_read_only_on_close__text(self.tcds.sds.result.exitcode_file, 'w') as f:
             f.write(str(exitcode))
 
-    def _custom_stdin_file_path(self) -> pathlib.Path:
-        configuration = self.stdin_configuration
-        if configuration.file_name is not None:
-            return configuration.file_name
-        else:
-            file_path = stdin_contents_file(self.tcds.sds)
-            misc_utils.write_new_text_file(file_path, configuration.string_contents)
-            return file_path
+    def _app_env_for_execute(self) -> ApplicationEnvironment:
+        env = self.environment_for_other_steps
+        return ApplicationEnvironment(
+            self.os_services,
+            env.proc_exe_settings,
+            env.tmp_dir__path_access.paths_access,
+            env.mem_buff_size,
+        )
