@@ -6,24 +6,24 @@ from exactly_lib.execution import phase_file_space
 from exactly_lib.execution import phase_step
 from exactly_lib.execution.configuration import ExecutionConfiguration
 from exactly_lib.execution.impl import phase_step_executors
-from exactly_lib.execution.impl.phase_step_execution import PhaseStepFailureResultConstructor, \
-    run_instructions_phase_step, execute_action_and_catch_implementation_exception
+from exactly_lib.execution.impl.phase_step_execution import run_instructions_phase_step, \
+    execute_action_and_catch_internal_error_exception
 from exactly_lib.execution.impl.phase_step_executors import InstructionEnvPostSdsGetter
 from exactly_lib.execution.impl.result import ActionThatRaisesPhaseStepFailureException
 from exactly_lib.execution.partial_execution.configuration import ConfPhaseValues, TestCase
+from exactly_lib.execution.partial_execution.impl.act_helper import ActHelper
 from exactly_lib.execution.partial_execution.impl.atc_execution import ActionToCheckExecutor
-from exactly_lib.execution.partial_execution.impl.atc_parsing import ActionToCheckParser
 from exactly_lib.execution.partial_execution.impl.symbol_validation import SymbolsValidator
 from exactly_lib.execution.partial_execution.result import PartialExeResult
 from exactly_lib.execution.result import ExecutionFailureStatus, PhaseStepFailure, PhaseStepFailureException
+from exactly_lib.tcfs.sds import SandboxDs, construct_at
 from exactly_lib.test_case import phase_identifier
-from exactly_lib.test_case.actor import ActionToCheck, Actor
+from exactly_lib.test_case.phases.act.actor import ActionToCheck, Actor
 from exactly_lib.test_case.phases.cleanup import PreviousPhase
 from exactly_lib.test_case.phases.instruction_environment import InstructionEnvironmentForPreSdsStep, \
     InstructionEnvironmentForPostSdsStep
-from exactly_lib.test_case.phases.setup import SetupSettingsBuilder
+from exactly_lib.test_case.phases.setup.settings_handler import SetupSettingsHandler
 from exactly_lib.test_case.result.failure_details import FailureDetails
-from exactly_lib.test_case_file_structure.sandbox_directory_structure import SandboxDirectoryStructure, construct_at
 from exactly_lib.util.file_utils.misc_utils import resolved_path_name
 from exactly_lib.util.name_and_value import NameAndValue
 from exactly_lib.util.process_execution.execution_elements import ProcessExecutionSettings
@@ -34,11 +34,11 @@ class Configuration(tuple):
     def __new__(cls,
                 conf_from_outside: ExecutionConfiguration,
                 conf_phase_values: ConfPhaseValues,
-                setup_settings_builder: SetupSettingsBuilder,
+                setup_settings_handler: SetupSettingsHandler,
                 ):
         return tuple.__new__(cls, (conf_from_outside,
                                    conf_phase_values,
-                                   setup_settings_builder))
+                                   setup_settings_handler))
 
     @property
     def exe_conf(self) -> ExecutionConfiguration:
@@ -49,13 +49,13 @@ class Configuration(tuple):
         return self[1]
 
     @property
-    def setup_settings_builder(self) -> SetupSettingsBuilder:
+    def setup_settings_handler(self) -> SetupSettingsHandler:
         return self[2]
 
 
-def execute(exe_conf: Configuration,
+def execute(configuration: Configuration,
             test_case: TestCase) -> PartialExeResult:
-    executor = _PartialExecutor(exe_conf,
+    executor = _PartialExecutor(configuration,
                                 test_case)
     return executor.execute()
 
@@ -67,10 +67,12 @@ def parse_atc_and_validate_symbols(actor: NameAndValue[Actor],
     """
     :raises PhaseStepFailureException
     """
-    action_to_check = ActionToCheckParser(actor).parse(test_case.act_phase)
+    act_helper = ActHelper(actor.name, test_case.act_phase)
+    action_to_check = act_helper.parse(actor.value)
     symbols_validator = SymbolsValidator(predefined_symbols,
                                          test_case,
-                                         action_to_check
+                                         action_to_check,
+                                         act_helper.failure_constructor,
                                          )
     symbols_validator.validate()
 
@@ -85,17 +87,18 @@ class _PartialExecutor:
         self.exe_conf = conf.exe_conf
         self.conf_values = conf.conf_phase_values
         self._test_case = test_case
-        self._setup_settings_builder = conf.setup_settings_builder
-        self._stdin_conf_from_setup = None
+        self._setup_settings_builder = conf.setup_settings_handler
         self._source_setup = None
         self._os_services = conf.exe_conf.os_services
-        self._act_phase_executor = None
+        self._act_phase_executor = _initial_atc_executor()
         self._action_to_check = None
         self._instruction_environment_pre_sds = None
 
         self.__sandbox_directory_structure = None
         self._action_to_check_outcome = None
         self._phase_tmp_space_factory = None
+        self._act_helper = ActHelper(conf.conf_phase_values.actor.name,
+                                     test_case.act_phase)
 
     def execute(self) -> PartialExeResult:
         try:
@@ -125,6 +128,7 @@ class _PartialExecutor:
                     self._act__validate_post_setup,
                     self._before_assert__validate_post_setup,
                     self._assert__validate_post_setup,
+                    self._act__validate_act_execution_input,
                     self._act__prepare,
                 ])
         except PhaseStepFailureException as ex:
@@ -193,7 +197,7 @@ class _PartialExecutor:
                 raise ex
 
     @property
-    def _sds(self) -> SandboxDirectoryStructure:
+    def _sds(self) -> SandboxDs:
         return self.__sandbox_directory_structure
 
     def _setup_pre_sds_environment(self,
@@ -205,7 +209,9 @@ class _PartialExecutor:
             ProcessExecutionSettings(self.conf_values.timeout_in_seconds,
                                      self.exe_conf.environ,
                                      ),
-            symbols)
+            symbols,
+            self.exe_conf.mem_buff_size,
+        )
 
     def _setup_post_sds_environment(self):
         self._construct_and_set_sds()
@@ -218,7 +224,8 @@ class _PartialExecutor:
     def _do_validate_symbols(self) -> SymbolTable:
         symbols_validator = SymbolsValidator(self.exe_conf.predefined_symbols,
                                              self._test_case,
-                                             self._action_to_check
+                                             self._action_to_check,
+                                             self._act_helper.failure_constructor,
                                              )
         symbols_validator.validate()
 
@@ -233,12 +240,11 @@ class _PartialExecutor:
     def _construct_and_set_act_phase_executor(self):
         self._act_phase_executor = self._construct_act_phase_executor()
 
-    def _act__parse_atc_executor(self):
-        parser = ActionToCheckParser(self.conf_values.actor)
-        self._action_to_check = parser.parse(self._test_case.act_phase)
+    def _act__parse_atc(self):
+        self._action_to_check = self._act_helper.parse(self.conf_values.actor.value)
 
     def _act__validate_pre_sds(self):
-        failure_con = PhaseStepFailureResultConstructor(phase_step.ACT__VALIDATE_PRE_SDS)
+        failure_con = self._act_helper.failure_constructor(phase_step.ACT__VALIDATE_PRE_SDS)
 
         def action():
             res = self._action_to_check.validate_pre_sds(self._instruction_environment_pre_sds)
@@ -248,26 +254,32 @@ class _PartialExecutor:
                                       FailureDetails.new_message(res.failure_message))
                 )
 
-        execute_action_and_catch_implementation_exception(action, failure_con)
+        execute_action_and_catch_internal_error_exception(action, failure_con)
 
     def _act__validate_post_setup(self):
-        failure_con = PhaseStepFailureResultConstructor(phase_step.ACT__VALIDATE_POST_SETUP)
+        failure_con = self._act_helper.failure_constructor(phase_step.ACT__VALIDATE_POST_SETUP)
 
-        execute_action_and_catch_implementation_exception(
+        execute_action_and_catch_internal_error_exception(
             self._act_phase_executor.validate_post_setup(failure_con.apply), failure_con)
 
-    def _act__prepare(self):
-        failure_con = PhaseStepFailureResultConstructor(phase_step.ACT__PREPARE)
+    def _act__validate_act_execution_input(self):
+        failure_con = self._act_helper.failure_constructor(phase_step.ACT__VALIDATE_EXE_INPUT)
 
-        execute_action_and_catch_implementation_exception(
+        execute_action_and_catch_internal_error_exception(
+            self._act_phase_executor.validate_execution_info(failure_con.apply), failure_con)
+
+    def _act__prepare(self):
+        failure_con = self._act_helper.failure_constructor(phase_step.ACT__PREPARE)
+
+        execute_action_and_catch_internal_error_exception(
             self._act_phase_executor.prepare(failure_con.apply),
             failure_con
         )
 
     def _act__execute(self):
-        failure_con = PhaseStepFailureResultConstructor(phase_step.ACT__EXECUTE)
+        failure_con = self._act_helper.failure_constructor(phase_step.ACT__EXECUTE)
 
-        return execute_action_and_catch_implementation_exception(
+        return execute_action_and_catch_internal_error_exception(
             self._act_phase_executor.execute(failure_con.apply), failure_con)
 
     def _before_assert__validate_pre_sds(self):
@@ -289,15 +301,12 @@ class _PartialExecutor:
                                     self._test_case.cleanup_phase)
 
     def _setup__main(self):
-        try:
-            run_instructions_phase_step(phase_step.SETUP__MAIN,
-                                        phase_step_executors.SetupMainExecutor(
-                                            self._os_services,
-                                            self._post_sds_main_environments(phase_identifier.SETUP),
-                                            self._setup_settings_builder),
-                                        self._test_case.setup_phase)
-        finally:
-            self._stdin_conf_from_setup = self._setup_settings_builder.stdin.as_stdin_configuration
+        run_instructions_phase_step(phase_step.SETUP__MAIN,
+                                    phase_step_executors.SetupMainExecutor(
+                                        self._os_services,
+                                        self._post_sds_main_environments(phase_identifier.SETUP),
+                                        self._setup_settings_builder.builder),
+                                    self._test_case.setup_phase)
 
     def _setup__validate_post_setup(self):
         run_instructions_phase_step(phase_step.SETUP__VALIDATE_POST_SETUP,
@@ -306,18 +315,19 @@ class _PartialExecutor:
                                     self._test_case.setup_phase)
 
     def _construct_act_phase_executor(self) -> ActionToCheckExecutor:
+        env_for_non_validate_steps = self._post_sds_environment(
+            self._phase_tmp_space_factory.for_phase__main(phase_identifier.ACT),
+            self.__post_sds_symbol_table,
+        )
         return ActionToCheckExecutor(
             self._action_to_check,
             self._post_sds_environment(
                 self._phase_tmp_space_factory.for_phase__validation(phase_identifier.ACT),
                 self._instruction_environment_pre_sds.symbols,
             ),
-            self._post_sds_environment(
-                self._phase_tmp_space_factory.for_phase__main(phase_identifier.ACT),
-                self.__post_sds_symbol_table,
-            ),
+            env_for_non_validate_steps,
             self._os_services,
-            self._stdin_conf_from_setup,
+            self._setup_settings_builder.as_act_execution_input(),
             self.exe_conf.exe_atc_and_skip_assertions,
         )
 
@@ -393,6 +403,7 @@ class _PartialExecutor:
             self.__sandbox_directory_structure,
             tmp_file_storage,
             symbols,
+            self.exe_conf.mem_buff_size,
         )
 
     def _final_failure_result_from(self, failure: PhaseStepFailure) -> PartialExeResult:
@@ -406,3 +417,7 @@ class _PartialExecutor:
                                 self.__sandbox_directory_structure,
                                 self._action_to_check_outcome,
                                 None)
+
+
+def _initial_atc_executor() -> Optional[ActionToCheckExecutor]:
+    return None
