@@ -2,7 +2,7 @@ from typing import Optional
 
 from exactly_lib.execution.failure_info import FailureInfo
 from exactly_lib.execution.result import ResultBase, ActionToCheckOutcome, ExecutionFailureStatus
-from exactly_lib.test_case_file_structure.sandbox_directory_structure import SandboxDirectoryStructure
+from exactly_lib.tcfs.sds import SandboxDs
 
 
 class PartialExeResult(ResultBase):
@@ -10,7 +10,7 @@ class PartialExeResult(ResultBase):
 
     def __init__(self,
                  status: Optional[ExecutionFailureStatus],
-                 sds: Optional[SandboxDirectoryStructure],
+                 sds: Optional[SandboxDs],
                  action_to_check_outcome: Optional[ActionToCheckOutcome],
                  failure_info: Optional[FailureInfo]):
         super().__init__(sds, action_to_check_outcome, failure_info)
