@@ -1,28 +1,32 @@
 from typing import List, Sequence
 
-from exactly_lib import program_info
+from exactly_lib.common.help import headers
 from exactly_lib.common.help.syntax_contents_structure import InvokationVariant, SyntaxElementDescription, \
     invokation_variant_from_args, cli_argument_syntax_element_description
 from exactly_lib.common.help.with_see_also_set import SyntaxElementDescriptionTree, InvokationVariantHelper
-from exactly_lib.definitions import instruction_arguments, formatting, misc_texts
+from exactly_lib.definitions import formatting, misc_texts
 from exactly_lib.definitions.argument_rendering.path_syntax import the_path_of
+from exactly_lib.definitions.cross_ref.app_cross_ref import CrossReferenceId
 from exactly_lib.definitions.cross_ref.name_and_cross_ref import cross_reference_id_list
 from exactly_lib.definitions.entity import concepts, syntax_elements, actors
 from exactly_lib.definitions.entity import types
-from exactly_lib.definitions.primitives import string_transformer
+from exactly_lib.definitions.primitives import string_transformer, program
 from exactly_lib.definitions.test_case.instructions import define_symbol
 from exactly_lib.definitions.test_case.instructions import instruction_names
 from exactly_lib.help.entities.syntax_elements.contents_structure import SyntaxElementDocumentation
+from exactly_lib.help.entities.utils import programs
+from exactly_lib.help.entities.utils.se_within_parens import OptionallyWithinParens
+from exactly_lib.impls import texts
+from exactly_lib.impls.types.path import path_relativities, relative_path_options_documentation as rel_path_doc
+from exactly_lib.impls.types.program import syntax_elements as pgm_syntax_elements
 from exactly_lib.processing import exit_values
-from exactly_lib.test_case_utils.documentation import relative_path_options_documentation as rel_path_doc
-from exactly_lib.test_case_utils.parse import path_relativities
-from exactly_lib.test_case_utils.parse.rel_opts_configuration import arg_config_with_name
-from exactly_lib.test_case_utils.program import syntax_elements as pgm_syntax_elements
-from exactly_lib.type_system.value_type import TypeCategory
+from exactly_lib.symbol.value_type import TypeCategory
 from exactly_lib.util.cli_syntax.elements import argument as a
 from exactly_lib.util.textformat.structure.core import ParagraphItem
 from exactly_lib.util.textformat.textformat_parser import TextParser
 
+_STDIN_ARGUMENT = a.Named('STDIN')
+
 
 class _Documentation(SyntaxElementDocumentation):
     def __init__(self):
@@ -36,9 +40,11 @@ class _Documentation(SyntaxElementDocumentation):
     def invokation_variants(self) -> List[InvokationVariant]:
         return [
             invokation_variant_from_args([
-                a.Single(a.Multiplicity.MANDATORY, self._pgm_and_args.element),
+                a.single_mandatory(self._pgm_and_args.element),
                 a.Single(a.Multiplicity.OPTIONAL,
-                         string_transformer.STRING_TRANSFORMATION_ARGUMENT),
+                         _STDIN_ARGUMENT),
+                a.Single(a.Multiplicity.OPTIONAL,
+                         a.Named(_OUTPUT_TRANSFORMATION)),
             ]),
         ]
 
@@ -46,25 +52,17 @@ class _Documentation(SyntaxElementDocumentation):
         return self._pgm_and_args.syntax_element_definitions + self._global_sed_list()
 
     def _global_sed_list(self) -> List[SyntaxElementDescription]:
-        return [self._transformation_sed()]
+        return [_stdin_sed(), _transformation_sed()]
 
-    def _transformation_sed(self) -> SyntaxElementDescription:
-        return cli_argument_syntax_element_description(
-            string_transformer.STRING_TRANSFORMATION_ARGUMENT,
-            _TEXT_PARSER.fnap(_TRANSFORMATION_DESCRIPTION),
-            [
-                invokation_variant_from_args([a.Single(a.Multiplicity.MANDATORY,
-                                                       string_transformer.TRANSFORMATION_OPTION)]),
-            ]
-        )
-
-    def see_also_targets(self) -> list:
+    def see_also_targets(self) -> List[CrossReferenceId]:
         info_refs = cross_reference_id_list([
             syntax_elements.SYMBOL_NAME_SYNTAX_ELEMENT,
+            syntax_elements.PROGRAM_ARGUMENT_SYNTAX_ELEMENT,
             syntax_elements.STRING_TRANSFORMER_SYNTAX_ELEMENT,
             syntax_elements.STRING_SYNTAX_ELEMENT,
             syntax_elements.LIST_SYNTAX_ELEMENT,
             syntax_elements.SHELL_COMMAND_LINE_SYNTAX_ELEMENT,
+            syntax_elements.STRING_SOURCE_SYNTAX_ELEMENT,
             concepts.SYMBOL_CONCEPT_INFO,
             types.PROGRAM_TYPE_INFO,
         ])
@@ -78,14 +76,13 @@ class _PgmAndArgs(SyntaxElementDescriptionTree):
     def __init__(self):
         self._pgm_for_arg_list = _ProgramWithArgumentList()
         self._shell_cmd_line = _ShellCommandLine()
-        self._arg = _ArgumentDoc()
 
     @property
     def element(self) -> a.Named:
         return a.Named('PGM-AND-ARGS')
 
     @property
-    def description_rest(self) -> Sequence[ParagraphItem]:
+    def before_invokation_variants(self) -> Sequence[ParagraphItem]:
         return _TEXT_PARSER.fnap(_PGM_AND_ARGS)
 
     @property
@@ -95,30 +92,29 @@ class _PgmAndArgs(SyntaxElementDescriptionTree):
             self._shell_cmd_line.as_invokation_variant,
         ]
 
-    def _pgm_for_arg_list_variant(self) -> InvokationVariant:
-        return invokation_variant_from_args([
-            a.Single(a.Multiplicity.MANDATORY, self._pgm_for_arg_list.element),
-            a.Single(a.Multiplicity.ZERO_OR_MORE, self._arg.element),
-        ],
-            _TEXT_PARSER.fnap(_PGM_WITH_ARG_LIST_INVOKATION_VARIANT_DESCRIPTION))
-
     @property
     def sub_syntax_element_definition_trees(self) -> List[SyntaxElementDescriptionTree]:
         return [
             self._pgm_for_arg_list,
-            self._arg,
         ]
 
+    def _pgm_for_arg_list_variant(self) -> InvokationVariant:
+        return invokation_variant_from_args([
+            a.single_mandatory(self._pgm_for_arg_list.element),
+            syntax_elements.PROGRAM_ARGUMENT_SYNTAX_ELEMENT.zero_or_more,
+        ],
+            _TEXT_PARSER.fnap(_PGM_WITH_ARG_LIST_INVOKATION_VARIANT_DESCRIPTION))
+
 
 class _ShellCommandLine(InvokationVariantHelper):
     @property
     def syntax(self) -> Sequence[a.ArgumentUsage]:
         return [
-            a.Single(a.Multiplicity.MANDATORY,
-                     a.Constant(instruction_names.SHELL_INSTRUCTION_NAME)
-                     ),
-            a.Single(a.Multiplicity.MANDATORY,
-                     syntax_elements.SHELL_COMMAND_LINE_SYNTAX_ELEMENT.argument)
+            a.single_mandatory(
+                a.Constant(instruction_names.SHELL_INSTRUCTION_NAME)
+            ),
+            a.single_mandatory(
+                syntax_elements.SHELL_COMMAND_LINE_SYNTAX_ELEMENT.argument)
         ]
 
     @property
@@ -132,24 +128,23 @@ class _ProgramWithArgumentList(SyntaxElementDescriptionTree):
         return a.Named('PGM-FOR-ARG-LIST')
 
     @property
-    def description_rest(self) -> Sequence[ParagraphItem]:
+    def before_invokation_variants(self) -> Sequence[ParagraphItem]:
         return _TEXT_PARSER.fnap(PGM_WITH_ARG_LIST_DESCRIPTION)
 
     @property
     def invokation_variants(self) -> Sequence[InvokationVariant]:
         return [
             self._exe_file(),
-            self._system_program(),
+            programs.system_program([]),
             self._sym_ref(),
-            self._python(),
+            programs.python_interpreter([]),
         ]
 
     @staticmethod
     def _exe_file() -> InvokationVariant:
         return invokation_variant_from_args(
             [
-                a.Single(a.Multiplicity.MANDATORY,
-                         instruction_arguments.PATH_ARGUMENT)
+                syntax_elements.PATH_SYNTAX_ELEMENT.single_mandatory
             ],
             rel_path_doc.path_element_relativity_paragraphs(
                 path_relativities.REL_OPTIONS_CONFIGURATION,
@@ -158,20 +153,6 @@ class _ProgramWithArgumentList(SyntaxElementDescriptionTree):
             )
         )
 
-    @staticmethod
-    def _system_program() -> InvokationVariant:
-        return invokation_variant_from_args(
-            [
-                a.Single(a.Multiplicity.MANDATORY,
-                         a.Constant(pgm_syntax_elements.SYSTEM_PROGRAM_TOKEN)
-                         ),
-                a.Single(a.Multiplicity.MANDATORY,
-                         syntax_elements.STRING_SYNTAX_ELEMENT.argument
-                         ),
-            ],
-            _TEXT_PARSER.paras(misc_texts.SYSTEM_PROGRAM_DESCRIPTION)
-        )
-
     @staticmethod
     def _sym_ref() -> InvokationVariant:
         return invokation_variant_from_args(
@@ -186,129 +167,75 @@ class _ProgramWithArgumentList(SyntaxElementDescriptionTree):
             _TEXT_PARSER.fnap(_SYM_REF_PROGRAM_DESCRIPTION)
         )
 
-    @staticmethod
-    def _python() -> InvokationVariant:
-        return invokation_variant_from_args(
-            [
+
+def _stdin_description_rest() -> List[ParagraphItem]:
+    ret_val = _TEXT_PARSER.fnap(_STDIN_DESCRIPTION)
+    ret_val += _TEXT_PARSER.fnap(_STDIN_OR_TRANSFORMATION_POSITION)
+    return ret_val
+
+
+def _stdin_sed() -> SyntaxElementDescription:
+    return cli_argument_syntax_element_description(
+        _STDIN_ARGUMENT,
+        _stdin_description_rest(),
+        [
+            invokation_variant_from_args([
                 a.Single(a.Multiplicity.MANDATORY,
-                         a.Option(pgm_syntax_elements.PYTHON_EXECUTABLE_OPTION_NAME))
-            ],
-            _TEXT_PARSER.fnap(_PYTHON_EXECUTABLE_DESCRIPTION)
-        )
-
-
-class _ArgumentDoc(SyntaxElementDescriptionTree):
-    @property
-    def element(self) -> a.Named:
-        return pgm_syntax_elements.ARGUMENT_SYNTAX_ELEMENT_NAME
-
-    @property
-    def description_rest(self) -> Sequence[ParagraphItem]:
-        return _TEXT_PARSER.fnap(_ARGUMENT_DESCRIPTION)
-
-    @property
-    def invokation_variants(self) -> List[InvokationVariant]:
-        return [
-            self._string(),
-            self._list(),
-            self._text_until_end_of_line(),
-            self._existing_path(
-                pgm_syntax_elements.EXISTING_FILE_OPTION_NAME,
-                _ARGUMENT__EXISTING_FILE_DESCRIPTION,
-            ),
-            self._existing_path(
-                pgm_syntax_elements.EXISTING_DIR_OPTION_NAME,
-                _ARGUMENT__EXISTING_DIR_DESCRIPTION,
-            ),
-            self._existing_path(
-                pgm_syntax_elements.EXISTING_PATH_OPTION_NAME,
-                _ARGUMENT__EXISTING_PATH_DESCRIPTION,
-            ),
+                         a.Option(program.STDIN_OPTION_NAME,
+                                  argument=syntax_elements.STRING_SOURCE_SYNTAX_ELEMENT.singular_name))
+            ]),
         ]
+    )
 
-    @staticmethod
-    def _existing_path(option: a.OptionName,
-                       description_rest: str) -> InvokationVariant:
-        return invokation_variant_from_args([
-            a.Single(a.Multiplicity.MANDATORY,
-                     a.Option(option)),
-            a.Single(a.Multiplicity.MANDATORY,
-                     PATH_OF_EXISTING_FILE_OPT_CONFIG.argument)
-        ],
-            _TEXT_PARSER.fnap(description_rest)
-        )
 
-    @staticmethod
-    def _text_until_end_of_line() -> InvokationVariant:
-        return invokation_variant_from_args([
-            a.Single(a.Multiplicity.MANDATORY,
-                     a.Constant(pgm_syntax_elements.REMAINING_PART_OF_CURRENT_LINE_AS_LITERAL_MARKER)),
-            a.Single(a.Multiplicity.MANDATORY,
-                     instruction_arguments.TEXT_UNTIL_END_OF_LINE_ARGUMENT)
-        ],
-            _TEXT_PARSER.fnap(_ARGUMENT__TEXT_UNTIL_END_OF_LINE_DESCRIPTION)
-        )
+def _transformation_description_rest() -> List[ParagraphItem]:
+    ret_val = _TEXT_PARSER.fnap(_TRANSFORMATION_DESCRIPTION)
+    ret_val += _TEXT_PARSER.fnap(_STDIN_OR_TRANSFORMATION_POSITION)
+    ret_val += texts.type_expression_has_syntax_of_primitive([
+        syntax_elements.STRING_TRANSFORMER_SYNTAX_ELEMENT.singular_name,
+    ])
+    return ret_val
 
-    @staticmethod
-    def _list() -> InvokationVariant:
-        return invokation_variant_from_args([
-            a.Single(a.Multiplicity.MANDATORY, syntax_elements.LIST_SYNTAX_ELEMENT.argument),
-        ],
-            _TEXT_PARSER.fnap(_ARGUMENT__LIST_DESCRIPTION)
-        )
 
-    @staticmethod
-    def _string() -> InvokationVariant:
-        return invokation_variant_from_args([
-            a.Single(a.Multiplicity.MANDATORY, syntax_elements.STRING_SYNTAX_ELEMENT.argument),
-        ],
-            _TEXT_PARSER.fnap(_ARGUMENT__STRING_DESCRIPTION)
-        )
-
-    @property
-    def sub_syntax_element_definition_trees(self) -> List[SyntaxElementDescriptionTree]:
-        return [
-            rel_path_doc.path_element_3(PATH_OF_EXISTING_FILE_OPT_CONFIG,
-                                        _TEXT_PARSER.paras(the_path_of('an existing file.')))
+def _transformation_sed() -> SyntaxElementDescription:
+    return SyntaxElementDescription(
+        _OUTPUT_TRANSFORMATION,
+        _transformation_description_rest(),
+        [
+            invokation_variant_from_args([a.Single(a.Multiplicity.MANDATORY,
+                                                   string_transformer.TRANSFORMATION_OPTION)]),
         ]
+    )
 
 
-PATH_OF_EXISTING_FILE_OPT_CONFIG = arg_config_with_name('PATH-OF-EXISTING',
-                                                        pgm_syntax_elements.EXE_FILE_REL_OPTION_ARG_CONF)
+_OUTPUT_TRANSFORMATION = 'TRANSFORMATION-OF-OUTPUT'
 
 EXECUTABLE_ARG = a.Named('EXECUTABLE')
 
 _TEXT_PARSER = TextParser({
-    'program_name': formatting.program_name(program_info.PROGRAM_NAME),
-    'string_type': types.STRING_TYPE_INFO.name,
-    'string_se': formatting.syntax_element_(syntax_elements.STRING_SYNTAX_ELEMENT),
-    'list_type': types.LIST_TYPE_INFO.name,
-    'list_se': formatting.syntax_element_(syntax_elements.LIST_SYNTAX_ELEMENT),
-    'path_type': types.PATH_TYPE_INFO.name,
-    'path_se': formatting.syntax_element_(syntax_elements.PATH_SYNTAX_ELEMENT),
     'program_type': types.PROGRAM_TYPE_INFO.name,
+    'PROGRAM': syntax_elements.PROGRAM_SYNTAX_ELEMENT.singular_name,
     'symbol': concepts.SYMBOL_CONCEPT_INFO.name,
     'hds': concepts.HDS_CONCEPT_INFO.name,
-    'SYMBOL_REFERENCE_SYNTAX_ELEMENT': formatting.syntax_element_(syntax_elements.SYMBOL_REFERENCE_SYNTAX_ELEMENT),
     'TRANSFORMATION': string_transformer.STRING_TRANSFORMATION_ARGUMENT.name,
-    'define_symbol': instruction_names.SYMBOL_DEFINITION_INSTRUCTION_NAME,
-    'TEXT_UNTIL_END_OF_LINE': instruction_arguments.TEXT_UNTIL_END_OF_LINE_ARGUMENT.name,
+    'define_symbol': formatting.InstructionName(instruction_names.SYMBOL_DEFINITION_INSTRUCTION_NAME),
+    'instruction': concepts.INSTRUCTION_CONCEPT_INFO.name,
     'SYMBOL_NAME': formatting.syntax_element_(syntax_elements.SYMBOL_NAME_SYNTAX_ELEMENT),
-    'THE_PYTHON_INTERPRETER': program_info.PYTHON_INTERPRETER_WHICH_CAN_RUN_THIS_PROGRAM,
-    'PATH_OF_EXISTING_FILE': PATH_OF_EXISTING_FILE_OPT_CONFIG.argument_syntax_name,
-    'ARGUMENT': formatting.syntax_element(pgm_syntax_elements.ARGUMENT_SYNTAX_ELEMENT_NAME.name),
+    'ARGUMENT': formatting.syntax_element(syntax_elements.PROGRAM_ARGUMENT_SYNTAX_ELEMENT.singular_name),
     'SHELL_COMMAND_LINE': formatting.syntax_element_(syntax_elements.SHELL_COMMAND_LINE_SYNTAX_ELEMENT),
     'executable_file': formatting.misc_name_with_formatting(misc_texts.EXECUTABLE_FILE),
     'FAIL': exit_values.EXECUTION__FAIL.exit_identifier,
     'shell_command': formatting.misc_name_with_formatting(misc_texts.SHELL_COMMAND),
-    'SYMBOLIC_LINKS_ARE_FOLLOWED': misc_texts.SYMBOLIC_LINKS_ARE_FOLLOWED,
     'relativity': formatting.misc_name_with_formatting(misc_texts.RELATIVITY),
-    'Note': misc_texts.NOTE_LINE_HEADER,
+    'Note': headers.NOTE_LINE_HEADER,
     'program_actor': formatting.entity_(actors.COMMAND_LINE_ACTOR),
     'actor_concept': formatting.concept_(concepts.ACTOR_CONCEPT_INFO),
+    'stdin': misc_texts.STDIN,
 })
 
-DOCUMENTATION = _Documentation()
+DOCUMENTATION = OptionallyWithinParens(
+    _Documentation(),
+)
 
 _PGM_AND_ARGS = """\
 A program followed by arguments until end of line.
@@ -332,80 +259,19 @@ An executable program.
 """
 
 _SYM_REF_PROGRAM_DESCRIPTION = """\
-Reference to a program that has been defined using the {define_symbol} instruction.
+Reference to a program that has been defined using the {define_symbol:emphasis} {instruction}.
 
 
-{SYMBOL_NAME} must have been defined as {program_type:a/q}.
-
-
-Arguments and transformations are appended to existing arguments and transformations
-of {SYMBOL_NAME}.
+Arguments, {stdin} and transformations are appended to the arguments, {stdin} and transformations
+of the referenced {program_type}.
 """
 
-_PYTHON_EXECUTABLE_DESCRIPTION = """\
-{THE_PYTHON_INTERPRETER}
+_STDIN_DESCRIPTION = """\
+Supplies {stdin} to the {program_type}.
 
 
-Since {program_name} is written in Python,
-the Python interpreter is guaranteed to be available on the system.
-"""
-
-_ARGUMENT_DESCRIPTION = """\
-An individual argument, or a list of arguments, in case of an unquoted reference
-to {list_type:a/q} {symbol:/q}.
-
-
-An argument list is an ordinary {list_type:/q} value, with additional features
-for text-until-end-of-line and references to existing files.
-"""
-
-_ARGUMENT__STRING_DESCRIPTION = """\
-{path_type:/q} values are handled as {string_type:/q} values the usual way -
-rendered as an absolute path.
-"""
-
-_ARGUMENT__LIST_DESCRIPTION = """\
-Elements of referenced lists are appended to the preceding arguments -
-argument lists are not nested.
-
-
-To pass a {list_se} as a single argument to a program,
-convert it to a {string_se} by surrounding it with quotes.
-(The elements will be separated by a single space.)
-"""
-
-_ARGUMENT__TEXT_UNTIL_END_OF_LINE_DESCRIPTION = """\
-The remaining part of the current line becomes a single argument.
-"""
-
-_ARGUMENT__EXISTING_FILE_DESCRIPTION = """\
-A {path_se}, with additional check for existence.
-
-
-{SYMBOLIC_LINKS_ARE_FOLLOWED}.
-
-
-Values are rendered as absolute paths.
-"""
-
-_ARGUMENT__EXISTING_DIR_DESCRIPTION = """\
-A {path_se}, with additional check for existence.
-
-
-{SYMBOLIC_LINKS_ARE_FOLLOWED}.
-
-
-Values are rendered as absolute paths.
-"""
-
-_ARGUMENT__EXISTING_PATH_DESCRIPTION = """\
-A {path_se}, with additional check for existence.
-
-
-{SYMBOLIC_LINKS_ARE_FOLLOWED}.
-
-
-Values are rendered as absolute paths.
+If the {program_type} is a reference to a PROGRAM {symbol},
+this {stdin} is appended to the {stdin} defined for the referenced {program_type}.
 """
 
 _TRANSFORMATION_DESCRIPTION = """\
@@ -413,11 +279,12 @@ Transforms the output from the program.
 
 
 Depending on the context, either stdout or stderr is transformed.
+"""
 
+_STDIN_OR_TRANSFORMATION_POSITION = """\
+{Note} Must appear on a separate line.
 
-Must appear on a separate line.
-
-If not, it will be interpreted as an {ARGUMENT}.
+(If not, it will be interpreted as arguments.)
 """
 
 _DIFFERENT_RELATIVITIES_FOR_PROGRAM_ACTOR = """\
