@@ -2,7 +2,7 @@ from typing import List
 
 from exactly_lib.help.entities.types.contents_structure import TypeDocumentation
 from exactly_lib.help.entities.types.objects import data_types, logic_types
-from exactly_lib.type_system.value_type import TypeCategory
+from exactly_lib.symbol.value_type import TypeCategory
 
 
 def all_types() -> List[TypeDocumentation]:
@@ -10,12 +10,14 @@ def all_types() -> List[TypeDocumentation]:
         data_types.STRING_DOCUMENTATION,
         data_types.LIST_DOCUMENTATION,
         data_types.PATH_DOCUMENTATION,
+        data_types.FILES_CONDITION_DOCUMENTATION,
+
+        logic_types.INTEGER_MATCHER_DOCUMENTATION,
         logic_types.LINE_MATCHER_DOCUMENTATION,
         logic_types.FILE_MATCHER_DOCUMENTATION,
         logic_types.FILES_MATCHER_DOCUMENTATION,
         logic_types.STRING_MATCHER_DOCUMENTATION,
         logic_types.STRING_TRANSFORMER_DOCUMENTATION,
-        logic_types.FILES_CONDITION_DOCUMENTATION,
         logic_types.PROGRAM_DOCUMENTATION,
     ]
 
