@@ -5,6 +5,9 @@ SECTION = 'section'
 INSTRUCTION = 'instruction'
 
 SYNTAX_TEXT = 'syntax-text'
+LITERAL_TEXT = 'syntax-text'
+
+CONSOLE_TEXT = 'console'
 
 TEXT_AS_HEADER = 'header-text'
 
