@@ -1,4 +1,4 @@
-from exactly_lib.test_case.actor import Actor
+from exactly_lib.test_case.phases.act.actor import Actor
 from exactly_lib.util.name_and_value import NameAndValue
 
 
