@@ -20,8 +20,8 @@ from exactly_lib.section_document.parse_source import ParseSource
 from exactly_lib.section_document.source_location import source_location_path_of_non_empty_location_path
 from exactly_lib.test_case import error_description
 from exactly_lib.test_case import test_case_doc
-from exactly_lib.test_case.actor import Actor
 from exactly_lib.test_case.os_services import OsServices
+from exactly_lib.test_case.phases.act.actor import Actor
 from exactly_lib.test_case.phases.configuration import ConfigurationBuilder
 from exactly_lib.util.file_utils.std import StdOutputFiles
 from exactly_lib.util.name_and_value import NameAndValue
@@ -64,6 +64,7 @@ class Configuration:
                  test_case_definition: TestCaseDefinition,
                  default_handling_setup: TestCaseHandlingSetup,
                  os_services: OsServices,
+                 mem_buff_size: int,
                  is_keep_sandbox: bool,
                  sandbox_root_dir_resolver: SandboxRootDirNameResolver =
                  sandbox_dir_resolving.mk_tmp_dir_with_prefix(program_info.PROGRAM_NAME + '-'),
@@ -71,6 +72,7 @@ class Configuration:
         self.default_handling_setup = default_handling_setup
         self.os_services = os_services
         self.test_case_definition = test_case_definition
+        self.mem_buff_size = mem_buff_size
         self.is_keep_sandbox = is_keep_sandbox
         self.exe_atc_and_skip_assertions = exe_atc_and_skip_assertions
         self.sandbox_root_dir_resolver = sandbox_root_dir_resolver
@@ -79,6 +81,7 @@ class Configuration:
         return ExecutionConfiguration(self.test_case_definition.predefined_properties.environ,
                                       self.os_services,
                                       self.sandbox_root_dir_resolver,
+                                      self.mem_buff_size,
                                       self.test_case_definition.predefined_properties.predefined_symbols,
                                       self.exe_atc_and_skip_assertions)
 
@@ -156,7 +159,7 @@ class _Parser(processing_utils.Parser):
         try:
             return file_parser.apply(test_case, source)
         except exceptions.ParseError as ex:
-            _ParseErrorHandler().visit(ex)
+            ex.accept(_ParseErrorHandler())
 
 
 class _ParseErrorHandler(exceptions.ParseErrorVisitor[None]):
@@ -205,5 +208,6 @@ class _Executor(processing_utils.Executor):
         return ExecutionConfiguration(ec.environ.copy(),
                                       ec.os_services,
                                       ec.sds_root_dir_resolver,
+                                      ec.mem_buff_size,
                                       ec.predefined_symbols.copy(),
                                       ec.exe_atc_and_skip_assertions)
