@@ -1,6 +1,7 @@
 from abc import ABC, abstractmethod
 from contextlib import contextmanager
-from typing import Callable, TypeVar, Iterable, Sequence, Tuple, Dict, Optional, ContextManager, Generic, Mapping, Any
+from typing import Callable, TypeVar, Iterable, Sequence, Tuple, Dict, Optional, ContextManager, Generic, Mapping, Any, \
+    Union, AbstractSet
 
 from exactly_lib.definitions import logic
 from exactly_lib.section_document.element_parsers import misc_utils
@@ -15,6 +16,7 @@ from exactly_lib.util.cli_syntax.option_parsing import matches
 from exactly_lib.util.cli_syntax.option_syntax import option_syntax
 from exactly_lib.util.messages import expected_found
 from exactly_lib.util.parse.token import Token
+from exactly_lib.util.str_ import english_text
 from exactly_lib.util.str_ import str_constructor
 from exactly_lib.util.str_.str_constructor import ToStringObject, StringConstructor
 
@@ -62,9 +64,13 @@ class TokenParser:
             self.error(error_message_format_string)
 
     def require_existing_valid_head_token(self, syntax_element_name: str):
-        if self._token_stream.is_null:
+        if self._lookahead_token_has_invalid_syntax():
+            self.require_head_token_has_valid_syntax(syntax_element_name)
+        elif self._token_stream.is_null:
             self.error('Missing ' + syntax_element_name)
-        self.require_head_token_has_valid_syntax(syntax_element_name)
+
+    def report_missing(self, syntax_element_name: str) -> T:
+        return self.error('Missing ' + syntax_element_name)
 
     def require_head_is_unquoted_and_equals(self, expected: str, error_message: ErrorMessageGenerator):
         if not self.head_is_unquoted_and_equals(expected):
@@ -78,6 +84,9 @@ class TokenParser:
                 self._lookahead_token_has_invalid_syntax()
         )
 
+    def has_valid_head_token_on_current_line(self) -> bool:
+        return not self.is_at_eol and self.has_valid_head_token()
+
     @property
     def head(self) -> Token:
         return self.token_stream.head
@@ -109,7 +118,7 @@ class TokenParser:
             ''
             if error_message_format_string == ''
             else
-            self._str_constructor_w_format_map(error_message_format_string + ':')
+            self._str_constructor_w_format_map(error_message_format_string + ': ')
         )
         self._require_head_token_has_valid_syntax(err_msg_header)
 
@@ -197,7 +206,7 @@ class TokenParser:
         """
 
         def constants_list() -> str:
-            return ' or '.join(['"' + constant + '"' for constant in expected_constants])
+            return english_text.or_sequence(['"' + constant + '"' for constant in expected_constants])
 
         if self.token_stream.is_null:
             return self.error(error_message_header_template + ': Missing {__CONSTANTS__}',
@@ -325,9 +334,10 @@ class TokenParser:
                     actual_string)
             )
 
-    def consume_optional_constant_string_that_must_be_unquoted_and_equal(self,
-                                                                         expected_constants: Sequence[str],
-                                                                         must_be_on_current_line: bool = True) -> str:
+    def consume_optional_constant_string_that_must_be_unquoted_and_equal(
+            self,
+            expected_constants: Union[Sequence[str], AbstractSet[str]],
+            must_be_on_current_line: bool = True) -> str:
         """
         Consumes the first token if it is an unquoted string that is equal to one of the expected string constants.
         :param expected_constants: collection of names=strings. Must support the Python 'in' operator
@@ -414,6 +424,10 @@ class TokenParser:
         return return_value_if_no_match
 
     def consume_optional_option(self, option_name: OptionName) -> bool:
+        """
+        :param option_name: Option to match
+        :returns Whether the option was present (and consumed) or not.
+        """
         if self.token_stream.is_null:
             return False
         elif matches(option_name, self.token_stream.head.source_string):
@@ -440,10 +454,7 @@ class TokenParser:
          :param argument_parser: Is given this parser object as argument, after the option token has been consumed.
          The return value from this function is returned if the option matches the head token
         """
-        if self.token_stream.is_null:
-            return return_value_if_no_match
-        elif matches(option_name, self.token_stream.head.source_string):
-            self.token_stream.consume()
+        if self.consume_optional_option(option_name):
             return argument_parser(self)
         else:
             return return_value_if_no_match
@@ -659,9 +670,7 @@ ParserFromTokenParser = Callable[[TokenParser], T]
 
 class ParserFromTokens(Generic[T], ABC):
     @abstractmethod
-    def parse(self,
-              token_parser: TokenParser,
-              must_be_on_current_line: bool = False) -> T:
+    def parse(self, token_parser: TokenParser) -> T:
         pass
 
 
@@ -708,7 +717,7 @@ def from_parse_source(source: ParseSource,
     finally:
         source.consume(tp.token_stream.position)
 
-    if consume_last_line_if_is_at_eol_after_parse and source.is_at_eol:
+    if consume_last_line_if_is_at_eol_after_parse and source.is_at_eol__except_for_space:
         source.consume_current_line()
     elif consume_last_line_if_is_at_eof_after_parse and source.is_at_eof:
         source.consume_current_line()
