@@ -15,15 +15,24 @@ class BeforeAssertPhaseInstruction(TestCaseInstructionWithSymbols):
 
     def validate_pre_sds(self,
                          environment: InstructionEnvironmentForPreSdsStep) -> svh.SuccessOrValidationErrorOrHardError:
+        """
+        :raises: :class:`HardErrorException`
+        """
         return svh.new_svh_success()
 
     def validate_post_setup(self,
                             environment: InstructionEnvironmentForPostSdsStep) -> svh.SuccessOrValidationErrorOrHardError:
+        """
+        :raises: :class:`HardErrorException`
+        """
         return svh.new_svh_success()
 
     def main(self,
              environment: InstructionEnvironmentForPostSdsStep,
              os_services: OsServices) -> sh.SuccessOrHardError:
+        """
+        :raises: :class:`HardErrorException`
+        """
         raise NotImplementedError()
 
 
