@@ -1,3 +1,5 @@
+from typing import Sequence
+
 from exactly_lib.util.cli_syntax import option_syntax
 from exactly_lib.util.cli_syntax.elements import argument as a
 from exactly_lib.util.parse.token import Token, TokenMatcher
@@ -7,6 +9,10 @@ def is_unquoted_and_equals(value: str) -> TokenMatcher:
     return _Equals(value, True)
 
 
+def is_unquoted_and_equals_any(accepted: Sequence[str]) -> TokenMatcher:
+    return _IsUnquotedAndEqualsAny(accepted)
+
+
 def is_option(option: a.OptionName) -> TokenMatcher:
     return _Equals(option_syntax.long_option_syntax(option.long), True)
 
@@ -22,3 +28,11 @@ class _Equals(TokenMatcher):
         if self.must_be_unquoted and token.is_quoted:
             return False
         return self.value == token.string
+
+
+class _IsUnquotedAndEqualsAny(TokenMatcher):
+    def __init__(self, accepted: Sequence[str]):
+        self._accepted = accepted
+
+    def matches(self, token: Token) -> bool:
+        return (not token.is_quoted) and token.string in self._accepted
