@@ -8,6 +8,10 @@ class ProcessExecutionSettings(tuple):
                 ):
         return tuple.__new__(cls, (timeout_in_seconds, environ))
 
+    @staticmethod
+    def with_timeout(timeout_in_seconds: Optional[int]) -> 'ProcessExecutionSettings':
+        return ProcessExecutionSettings(timeout_in_seconds=timeout_in_seconds)
+
     @staticmethod
     def with_environ(environ: Dict[str, str]) -> 'ProcessExecutionSettings':
         return ProcessExecutionSettings(environ=environ)
